# Test Package
For the ```iCanCode``` python advanced class. Source:
```python
def UpperName(name):
  newname = ""
  splitName = name.split(" ")
  for name in splitName:
    newname += name.capatalize() + " 
  return newname[1:]
```
That's it! Your's truly, DaGoodHacker...